<?php

/**
 * dev config for the new eluhr/yii2-flysystem-rest-api
 */


/**
 * This is a sample dev config for eluhr/yii2-flysystem package development
 *
 * To include this config in your app, you'll have to:
 * - add this config and the migration path in your local.env
 *   ```
 *   APP_CONFIG_FILE=@root/config/_fs_dev.php
 *   APP_MIGRATION_LOOKUP=@vendor/eluhr/yii2-flysystem-rest-api/src/migrations
 *   ```
 * - add host-volume in your dev docker-compose file(s) with permissions, so that the webserver can write in
 *   example:
 *   ```
 *   # fs dev local fs
 *   - ./_host-volumes/storage/fs-local:/mnt/storage/fs-local:delegated
 *   ```
 */

use yii\helpers\Url;

return [
    'components' => [
        // this is the component for one filesystem
        'fsLocal' => [
            'class' => \eluhr\flysystemRestApi\components\FileStorage::class,
            'storageId' => 'fsLocal',
            'adapter' => function() {
                return new League\Flysystem\Local\LocalFilesystemAdapter(
                    '/mnt/storage/fs-local'
                );
            },
            // these are examples for 'storage plugins'
            'storageItemPlugins' => [
                // \eluhr\flysystemRestApi\plugins\TagPlugin::class, // Needs dev/el branch for rest-api. Run migration in @vendor/eluhr/yii2-flysystem-rest-api/src/migrations/plugins/tag
                // \eluhr\flysystemRestApi\plugins\CategoryPlugin::class, // Needs dev/el branch for rest-api. Run migration in @vendor/eluhr/yii2-flysystem-rest-api/src/migrations/plugins/category
                \eluhr\flysystemRestApi\plugins\MimeTypePlugin::class,
                \eluhr\flysystemRestApi\plugins\FileExtensionPlugin::class,
                [
                    'class'     => \eluhr\flysystemRestApi\plugins\ClipBoardValuesPlugin::class,
                    'callbacks' => [

                        'url' => function($item) {
                            if ($item->type === 'file') {
                                $route = '/img/download';
                                if (in_array(pathinfo($item->name, PATHINFO_EXTENSION), ['png', 'jpg', 'jpeg'])) {
                                    $route = '/img/stream';
                                }
                                return Url::to(
                                    [
                                        $route,
                                        'path' => implode(DIRECTORY_SEPARATOR, array_filter([$item->path, $item->name]))
                                    ]
                                );
                            }
                            return null;
                        },
                        'url2' => function($item) {
                            if ($item->type === 'file') {
                                $route = '/img/download';
                                if (in_array(pathinfo($item->name, PATHINFO_EXTENSION), ['png', 'jpg', 'jpeg'])) {
                                    $route = '/img/stream';
                                }
                                return Url::to(
                                    [
                                        $route,
                                        'path' => implode(DIRECTORY_SEPARATOR, array_filter([$item->path, $item->name]))
                                    ]
                                );
                            }
                            return null;
                        },
                        'url3' => function($item) {
                            if ($item->type === 'dir') {
                                return implode(DIRECTORY_SEPARATOR, array_filter([$item->path, $item->name]));
                            }
                            return null;
                        }
                    ]
                ],
                [
                    'class' => \eluhr\flysystemRestApi\plugins\FilePreviewPlugin::class,
                    'urlCallback' => function($item) {
                        if ($item->type === 'file') {
                            return Url::to(['/img/stream', 'path' =>  implode(DIRECTORY_SEPARATOR, array_filter([$item->path, $item->name]))]);
                        }
                        return null;
                    }
                ],
                [
                    'class' => \eluhr\flysystemRestApi\plugins\ThumbnailPlugin::class,
                    'urlCallback' => function($item) {
                        if ($item->type === 'file' && in_array(pathinfo($item->name, PATHINFO_EXTENSION), ['png', 'jpg', 'jpeg', 'gif'])) {
                            return Url::to(['/img/stream', 'path' =>  implode(DIRECTORY_SEPARATOR, array_filter([$item->path, $item->name]))]);
                        }
                        return null;
                    }
                ]
            ],
        ],
        'urlManager' => [
            'rules' => [
                'img/stream' => 'fs-local/api/stream',
                'img/download' => 'fs-local/api/download',
            ],
            'ignoreLanguageUrlPatterns' => [
                '#^img/stream#' => '#^img/stream#',
                '#^img/download#' => '#^img/download#',
                '#fs-local/api#' => '#fs-local/api#'
            ],
        ],
    ],
    'modules' => [
        // this is the rest-api module, which requires a valid flysystemRestApi\components\FileStorage id
        // for dev we have a simple backend controller inside this module, but this should be slitted...
        'fs-local' => [
            'class' => eluhr\flysystemRestApi\Module::class,
            'fileStorage' => 'fsLocal',
            'backendLayout' => '@backend/views/layouts/box',
        ],
    ],
];
